@@ -1,7 +1,6 @@
 """I/O writers."""
 
 import json
-import logging
 from io import TextIOWrapper
 from typing import Any
 
@@ -20,12 +19,13 @@ class ResultEncoder(json.JSONEncoder):
         raise NotImplementedError()
 
 
-def write_results(output_file: TextIOWrapper | None, results: Results) -> None:
+def write_results(output_file: TextIOWrapper, results: Results) -> None:
     """Saves the results."""
 
-    if output_file is None:
-        logger = logging.getLogger('io')
-        logger.debug('no output file specified, skipping writing results..')
-        return
-
-    json.dump(results, output_file, indent=4, cls=ResultEncoder, sort_keys=True)
+    json.dump(
+        results,
+        output_file,
+        indent=4,
+        cls=ResultEncoder,
+        sort_keys=True,
+    )
